==> speech-analytic-testing_0.10.2_database.tar.gz: database/mssql/procedures/BulkAbilityCognitive.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkAbilityCognitive]
AS
BEGIN
	SET NOCOUNT ON
	--select * from Dummy 
	--truncate table Dummy
	/*
	CREATE TABLE TMP_EVALUATIONPLANABILITY(
		VCC VARCHAR(50),
		ProcessId VARCHAR(50),
		EvaluationPlanId  VARCHAR(200),
		ID VARCHAR(250),
		Section  VARCHAR(50),
		Part VARCHAR(50),
		QueryId VARCHAR(50),
		TranscriptionId VARCHAR(200),
		NluId VARCHAR(50),
		IntentName VARCHAR(50),
		EndDate VARCHAR(50),
		Channel VARCHAR(50),
		Campaign VARCHAR(50)
	)
	*/

	/*insert into DummyEvaluationPlanAbility ([VCC]) values ('BULK')
	insert into TMP_EVALUATIONPLANABILITY ([VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign])  
	SELECT [VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign]
	  FROM [dbo].[#AbilityCognitiveTemp]
	*/  

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT ACTMP.[VCC],
							ACTMP.[EvaluationPlanId] 'EVALUATION_PLAN_ID'
						FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
						WHERE ACTMP.[VCC] IS NOT NULL 
							AND ACTMP.[EvaluationPlanId] IS NOT NULL

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'
			
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	
	/* Script para actualizar a puntaje 100 la calificacion de cada habilidad retornada por luis */
	/*
	SELECT EP.[Description],
			ACTMP.[ID],
			I.[IntentId],
			I.[Name],
			A.[Title],
			AEP.Completed,
			ER.[Qualification],
			I.[AppId]
			*/
	UPDATE ER 
		SET ER.[Qualification] = (AEF.[Score] * S.[Value])/100,
			ER.[ScoreDescription] = S.[Description]
		FROM EvaluationPlan EP (NOLOCK)
		LEFT JOIN InteractionEvaluationPlan IEP (NOLOCK)
			ON IEP.[Instance] = EP.[Instance]
				AND IEP.[IdEvaluationPlan] = EP.[ID]
		LEFT JOIN EvaluationFormat EF (NOLOCK) 
			ON EF.[Instance] = EP.[Instance]
				AND EF.[ID] = EP.[IdEvaluationFormat]
		LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK)
			ON AEF.[Instance] = EP.[Instance]
				AND AEF.[IdEvaluationFormat] = EF.[ID] --EP.[IdEvaluationFormat]
		LEFT JOIN Score S (NOLOCK)
			ON S.[IdAbility] = AEF.[IdAbility]
				AND S.[Value] = 100
		LEFT JOIN Ability A (NOLOCK) 
			ON A.[Instance] = EP.[Instance]
				AND A.[ID] = AEF.[IdAbility]
		LEFT JOIN Intent I (NOLOCK) 
			ON I.[VCC] = EP.[Instance]
				AND I.[IntentId] = A.[QueryName]
		LEFT JOIN AuditorEvaluationPlan AEP (NOLOCK)
			ON AEP.[IdEvaluationPlan] = EP.[ID]
				AND AEP.[IdInteraction] = IEP.[IdInteraction]
		LEFT JOIN EvaluationResult ER (NOLOCK)
			ON ER.[Instance] = EP.[Instance] 
				AND ER.[IdEvaluationFormat] = EF.[ID]
				AND ER.[IdInteraction] = IEP.[IdInteraction]
		INNER JOIN [#AbilityCognitiveTemp] ACTMP 
			ON ACTMP.[VCC] = EP.[Instance] 
				AND ACTMP.[EvaluationPlanId] = EP.[ID]
				AND ACTMP.[ID] = IEP.[IdInteraction]
				AND ACTMP.[IntentName] = I.[Name]
		WHERE ACTMP.[EvaluationPlanId] = EP.[ID]
			AND ACTMP.[ID] = IEP.[IdInteraction]
			AND ACTMP.[IntentName] = I.[Name]
			AND AEF.[IdAbility] = ER.[IdAbility]
			AND A.[ID] IS NOT NULL
			AND ER.[IdAuditor] = 'SPEECH'

	/* Script para actualizar la tabla AuditorEvaluationPlan a Completed y Suma de Scores de la evaluacion */
	UPDATE AEP
		SET --AEP.[Completed] = '1',
			AEP.[Completed] = CASE WHEN AEPR.[Evaluation_Mode] = 'X' AND AEPR.[MinAutomaticQualification] <= AEPR.[SCORE] THEN '0' ELSE '1' END,
			AEP.[Score] = AEPR.[SCORE]
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		LEFT JOIN (
			SELECT AEP.[Instance],
				AEP.[IdEvaluationPlan],
				AEP.[IdInteraction],
				EP.[Evaluation_Mode],
				EF.[MinAutomaticQualification],
				SUM(ER.[Qualification]) AS SCORE
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN EvaluationPlan EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.[ID] = AEP.[IdEvaluationPlan] 
			LEFT JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = AEP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			LEFT JOIN EvaluationResult ER (NOLOCK)
				ON ER.[Instance] = AEP.[Instance]
					AND ER.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND ER.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK) 
				ON AEF.[Instance] = EP.[Instance]
					AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			LEFT JOIN (SELECT DISTINCT ACTMP.[VCC],
									ACTMP.[EvaluationPlanId]
								FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
								WHERE ACTMP.[VCC] IS NOT NULL 
									AND ACTMP.[EvaluationPlanId] IS NOT NULL) TMP 
				ON TMP.[VCC] = AEP.[Instance]
					AND TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
			WHERE TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
				AND AEP.[IdAuditor] = 'SPEECH'
			GROUP BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction], EP.[Evaluation_Mode], EF.[MinAutomaticQualification]
		) AEPR 
		ON AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
		WHERE AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
	
	;
	/****************************************************************************************/
	/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/****************************************************************************************/
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
	--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
	WITH CTEFP AS (
		SELECT DISTINCT 
				ER.[Instance],
				ER.[IdInteraction],
				ER.[IdEvaluationPlan],
				ER.[IdEvaluationFormat],
				ER.[IdAbility],
				CASE WHEN ER.[Qualification] = 0 AND AEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
				AEF.[Penalizes],
				CASE AEF.[Penalizes]
					WHEN 'INT' THEN ER.[IdInteraction] 
					WHEN 'GRP' THEN ER.[IdGroup] 
					WHEN 'SGR' THEN ER.[IdSubGroup] 
				END 'PenalizedOn',
				RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[Qualification] = 0 THEN 1 ELSE 0 END 
					ORDER BY CASE AEF.[Penalizes]
					WHEN 'INT' THEN 1 
					WHEN 'GRP' THEN 2 
					WHEN 'SGR' THEN 3 
				END)
			FROM [EvaluationResult] ER (NOLOCK) 
			LEFT JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
				ON AEF.[Instance] = ER.[Instance] 
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp]) 
				AND ER.[Qualification] = 0 
				AND AEF.[Penalizes] <> 'NO'
			-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
	),

	-- ALMACENAMOS EL RESULTADO AGRUPADO DE LAS EVALUACIONES EN UNA TABLA VARIABLE PARA HACER UN CRUCE DIRECTO CON
	--  LA TABLA AuditorEvaluationPlan
	CTEFS AS (
		SELECT ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				SUM(ER.[Qualification]) 'TOTAL_SCORE',
				SUM(ER.[Qualification] * CASE WHEN FP.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE'
		
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN (
				-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
				--  POR LA MAS PRIORITARIA (FP.[RN])
				SELECT DISTINCT FP.[Instance],
								FP.[IdEvaluationPlan], 
								FP.[Penalized],
								FP.[Penalizes], 
								FP.[PenalizedOn]
					FROM CTEFP FP (NOLOCK)
					WHERE FP.[Penalizes] <> 'NO'
						AND FP.[RN] = 1
			) FP
				ON FP.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = FP.[IdEvaluationPlan]
					AND CASE FP.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP.[PenalizedOn]
					AND FP.[Penalized] = 1
			--WHERE ER.[Instance] = 'multisalud'
			WHERE ER.[Instance] = FP.[Instance]
				AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp])
			GROUP BY ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction]
	)
	--SELECT * FROM CTEFS

	-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
	UPDATE AEP 
		SET AEP.[Score] = FS.[PENALIZED_SCORE]
		FROM AuditorEvaluationPlan AEP 
		LEFT JOIN CTEFS FS (NOLOCK) 
			ON FS.[Instance] = AEP.[Instance] 
				AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
				AND FS.[IdInteraction] = AEP.[IdInteraction]
		WHERE FS.[Instance] IS NOT NULL
		
	/*************************************************************************************/
	/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/*************************************************************************************/
	
	DROP TABLE [dbo].[#AbilityCognitiveTemp];
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/BulkAbilityCognitive.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[BulkAbilityCognitive]
AS
BEGIN
	SET NOCOUNT ON
	--select * from Dummy 
	--truncate table Dummy
	/*
	CREATE TABLE TMP_EVALUATIONPLANABILITY(
		VCC VARCHAR(50),
		ProcessId VARCHAR(50),
		EvaluationPlanId  VARCHAR(200),
		ID VARCHAR(250),
		Section  VARCHAR(50),
		Part VARCHAR(50),
		QueryId VARCHAR(50),
		TranscriptionId VARCHAR(200),
		NluId VARCHAR(50),
		IntentName VARCHAR(50),
		EndDate VARCHAR(50),
		Channel VARCHAR(50),
		Campaign VARCHAR(50)
	)
	*/

	/*insert into DummyEvaluationPlanAbility ([VCC]) values ('BULK')
	insert into TMP_EVALUATIONPLANABILITY ([VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign])  
	SELECT [VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign]
	  FROM [dbo].[#AbilityCognitiveTemp]
	*/  

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT ACTMP.[VCC],
							ACTMP.[EvaluationPlanId] 'EVALUATION_PLAN_ID'
						FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
						WHERE ACTMP.[VCC] IS NOT NULL 
							AND ACTMP.[EvaluationPlanId] IS NOT NULL

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'
			
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	
	/* Script para actualizar a puntaje 100 la calificacion de cada habilidad retornada por luis */
	/*
	SELECT EP.[Description],
			ACTMP.[ID],
			I.[IntentId],
			I.[Name],
			A.[Title],
			AEP.Completed,
			ER.[Qualification],
			I.[AppId]
			*/
	UPDATE ER 
		SET ER.[Qualification] = (AEF.[Score] * S.[Value])/100,
			ER.[ScoreDescription] = S.[Description]
		FROM EvaluationPlan EP (NOLOCK)
		LEFT JOIN InteractionEvaluationPlan IEP (NOLOCK)
			ON IEP.[Instance] = EP.[Instance]
				AND IEP.[IdEvaluationPlan] = EP.[ID]
		LEFT JOIN EvaluationFormat EF (NOLOCK) 
			ON EF.[Instance] = EP.[Instance]
				AND EF.[ID] = EP.[IdEvaluationFormat]
		LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK)
			ON AEF.[Instance] = EP.[Instance]
				AND AEF.[IdEvaluationFormat] = EF.[ID] --EP.[IdEvaluationFormat]
		LEFT JOIN Score S (NOLOCK)
			ON S.[IdAbility] = AEF.[IdAbility]
				AND S.[Value] = 100
		LEFT JOIN Ability A (NOLOCK) 
			ON A.[Instance] = EP.[Instance]
				AND A.[ID] = AEF.[IdAbility]
		LEFT JOIN Intent I (NOLOCK) 
			ON I.[VCC] = EP.[Instance]
				AND I.[IntentId] = A.[QueryName]
		LEFT JOIN AuditorEvaluationPlan AEP (NOLOCK)
			ON AEP.[IdEvaluationPlan] = EP.[ID]
				AND AEP.[IdInteraction] = IEP.[IdInteraction]
		LEFT JOIN EvaluationResult ER (NOLOCK)
			ON ER.[Instance] = EP.[Instance] 
				AND ER.[IdEvaluationFormat] = EF.[ID]
				AND ER.[IdInteraction] = IEP.[IdInteraction]
		INNER JOIN [#AbilityCognitiveTemp] ACTMP 
			ON ACTMP.[VCC] = EP.[Instance] 
				AND ACTMP.[EvaluationPlanId] = EP.[ID]
				AND ACTMP.[ID] = IEP.[IdInteraction]
				AND ACTMP.[IntentName] = I.[Name]
		WHERE ACTMP.[EvaluationPlanId] = EP.[ID]
			AND ACTMP.[ID] = IEP.[IdInteraction]
			AND ACTMP.[IntentName] = I.[Name]
			AND AEF.[IdAbility] = ER.[IdAbility]
			AND A.[ID] IS NOT NULL
			AND ER.[IdAuditor] = 'SPEECH'

	/* Script para actualizar la tabla AuditorEvaluationPlan a Completed y Suma de Scores de la evaluacion */
	UPDATE AEP
		SET --AEP.[Completed] = '1',
			AEP.[Completed] = CASE WHEN AEPR.[Evaluation_Mode] = 'X' AND AEPR.[MinAutomaticQualification] <= AEPR.[SCORE] THEN '0' ELSE '1' END,
			AEP.[Score] = AEPR.[SCORE],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		LEFT JOIN (
			SELECT AEP.[Instance],
				AEP.[IdEvaluationPlan],
				AEP.[IdInteraction],
				EP.[Evaluation_Mode],
				EF.[MinAutomaticQualification],
				SUM(ER.[Qualification]) AS SCORE
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN EvaluationPlan EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.[ID] = AEP.[IdEvaluationPlan] 
			LEFT JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = AEP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			LEFT JOIN EvaluationResult ER (NOLOCK)
				ON ER.[Instance] = AEP.[Instance]
					AND ER.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND ER.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK) 
				ON AEF.[Instance] = EP.[Instance]
					AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			LEFT JOIN (SELECT DISTINCT ACTMP.[VCC],
									ACTMP.[EvaluationPlanId]
								FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
								WHERE ACTMP.[VCC] IS NOT NULL 
									AND ACTMP.[EvaluationPlanId] IS NOT NULL) TMP 
				ON TMP.[VCC] = AEP.[Instance]
					AND TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
			WHERE TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
				AND AEP.[IdAuditor] = 'SPEECH'
			GROUP BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction], EP.[Evaluation_Mode], EF.[MinAutomaticQualification]
		) AEPR 
		ON AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
		WHERE AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
	
	;
	/****************************************************************************************/
	/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/****************************************************************************************/
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
	--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
	WITH CTEFP AS (
		SELECT DISTINCT 
				ER.[Instance],
				ER.[IdInteraction],
				ER.[IdEvaluationPlan],
				ER.[IdEvaluationFormat],
				ER.[IdAbility],
				CASE WHEN ER.[Qualification] = 0 AND AEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
				AEF.[Penalizes],
				CASE AEF.[Penalizes]
					WHEN 'INT' THEN ER.[IdInteraction] 
					WHEN 'GRP' THEN ER.[IdGroup] 
					WHEN 'SGR' THEN ER.[IdSubGroup] 
				END 'PenalizedOn',
				RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[Qualification] = 0 THEN 1 ELSE 0 END 
					ORDER BY CASE AEF.[Penalizes]
					WHEN 'INT' THEN 1 
					WHEN 'GRP' THEN 2 
					WHEN 'SGR' THEN 3 
				END)
			FROM [EvaluationResult] ER (NOLOCK) 
			LEFT JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
				ON AEF.[Instance] = ER.[Instance] 
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp]) 
				AND ER.[Qualification] = 0 
				AND AEF.[Penalizes] <> 'NO'
			-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
	),

	-- ALMACENAMOS EL RESULTADO AGRUPADO DE LAS EVALUACIONES EN UNA TABLA VARIABLE PARA HACER UN CRUCE DIRECTO CON
	--  LA TABLA AuditorEvaluationPlan
	CTEFS AS (
		SELECT ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				SUM(ER.[Qualification]) 'TOTAL_SCORE',
				SUM(ER.[Qualification] * CASE WHEN FP.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE'
		
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN (
				-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
				--  POR LA MAS PRIORITARIA (FP.[RN])
				SELECT DISTINCT FP.[Instance],
								FP.[IdEvaluationPlan], 
								FP.[Penalized],
								FP.[Penalizes], 
								FP.[PenalizedOn]
					FROM CTEFP FP (NOLOCK)
					WHERE FP.[Penalizes] <> 'NO'
						AND FP.[RN] = 1
			) FP
				ON FP.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = FP.[IdEvaluationPlan]
					AND CASE FP.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP.[PenalizedOn]
					AND FP.[Penalized] = 1
			--WHERE ER.[Instance] = 'multisalud'
			WHERE ER.[Instance] = FP.[Instance]
				AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp])
			GROUP BY ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction]
	)
	--SELECT * FROM CTEFS

	-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
	UPDATE AEP 
		SET AEP.[Score] = FS.[PENALIZED_SCORE],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP 
		LEFT JOIN CTEFS FS (NOLOCK) 
			ON FS.[Instance] = AEP.[Instance] 
				AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
				AND FS.[IdInteraction] = AEP.[IdInteraction]
		WHERE FS.[Instance] IS NOT NULL
		
	/*************************************************************************************/
	/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/*************************************************************************************/
	
	DROP TABLE [dbo].[#AbilityCognitiveTemp];
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
